@@ -10,8 +10,8 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
-#ifndef KTPRINTOPT_H
-#define KTPRINTOPT_H
+#ifndef CRONTABPRINTERWIDGET_H
+#define CRONTABPRINTERWIDGET_H
 
 #include <QWidget>
 
@@ -29,7 +29,7 @@ public:
 	/**
 	 * Constructs the dialog, if root is true the print all users is not disabled
 	 */
-	CrontabPrinterWidget(bool root = false);
+	explicit CrontabPrinterWidget(bool root = false);
 
 	~CrontabPrinterWidget();
 
